import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		'#F0F8FF', '#00FFFF', '#8A2BE2', '#77FF00', '#5F9EA0', '#6495ED', '#DC143C', '#FFD700', '#FF8C00', '#FF1493',"#ADFF2F"
		  ];

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/Tejaswi221/7280644a229d95d67da3eae703f31618/raw/90c30afd44d44101d6d76fce68c40a3c962e2566/Sales_of_Companies.csv';
// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Format axes text
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Render Pie Chart on the canvas
const render = (data, total) => {
  const pieData = pie().value(d=>d.Sales)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Object for generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Sales));
  
  // Render text on each section
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Sales/1000))+"K")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  // Render legend for the data
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Sales));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Company);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Sales/1000))+"K");
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Sales = +d.Sales;
    total += d.Sales
  });
	render(data,total);
};
run();